package ui

import (
	"context"
	"time"

	def "git.pbiernat.io/egommerce/api-entities/http"
	"git.pbiernat.io/egommerce/catalog-service/internal/service"
)

func GetProductList(srv *service.CatalogService, categoryID int, reqID string) ([]def.GetProductResponse, error) {
	ctx := context.Background()
	res := []def.GetProductResponse{}

	products, err := srv.GetProductList(ctx, reqID, categoryID)
	if err != nil {
		return nil, err
	}

	for _, v := range products {
		product := def.GetProductResponse{
			ID:        v.ID,
			PID:       v.PID,
			Name:      v.Name,
			Price:     v.Price,
			CreatedAt: time.Duration(v.CreatedAt.Time.Unix()),
		}
		if v.UpdatedAt.Time.Unix() > 0 {
			product.UpdatedAt = time.Duration(v.UpdatedAt.Time.Unix())
		}
		res = append(res, product)
	}

	return res, nil
}

func AddProductToBasket(srv *service.CatalogService, productID, qty int, basketID, reqID string) (*def.AddProductToBasketResponse, error) {
	ctx := context.Background()
	res := &def.AddProductToBasketResponse{}

	product, err := srv.GetProduct(ctx, reqID, productID)
	if err != nil {
		return res, err
	}
	res.ProductID = product.ID

	if err := srv.AddProductToBasket(reqID, basketID, productID, qty); err != nil {
		return res, err
	}
	res.BasketID = basketID

	return res, nil
}

func RemoveProductFromBasket(srv *service.CatalogService, productID, qty int, basketID, reqID string) (*def.RemoveProductFromBasketResponse, error) {
	res := &def.RemoveProductFromBasketResponse{}
	if err := srv.RemoveProductFromBasket(reqID, basketID, productID, qty); err != nil {
		return res, err
	}
	res.BasketID = basketID

	return res, nil
}
